## ToDo
- [x] API ~~endpoint~~
- [ ] RSS support
- [x] Docker support
- [x] Page support for debe
- [x] Author page and ~~last entrys~~
- [x] Optioanl displaying for pinned
- [x] Optional displaying author nickname
- [x] Sorthing for entries ~~today~~ and nice
- [x] ~~Feedback~~ and donate page
- [ ] URL replace support for alternative front-ends (e.g: twitter to nitter)
